<?php


namespace App\Http\Controllers\Api;
use App\Http\Params\ProblemParam;
use App\Models\User;
use App\Models\UserInfoModel;
use App\Models\UserVipLogModel;
use App\Models\VipModel;
use App\Services\UserService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use PHPUnit\Util\Exception;

class UserController extends Controller
{
    protected $userService;

    public function __construct(){
        $this->userService = new UserService();
    }

    /**
     * 设置密码
     */
    public function setpass(Request $request){
        $validator = Validator::make($request->all(), [
            'password' => 'required|string',
        ],[
            'password.required'=>"密码必须",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        $user = auth('api')->user();
        $user->password = $request->password;
        if($user->save()){
            return response()->json(['message'=>"设置成功"]);
        }else{
            return $this->response->errorForbidden("设置失败");
        }
    }

    /**
     * 选择性别
     */
    public function checksex(Request $request){
        $user = auth('api')->user();
        $validator = Validator::make($request->all(), [
            'sex' => 'required'
        ], [
            'mobile.required'=>"性别必须",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        //dd($user);
        $user->sex = $request->sex;
        if (!$user->save()) {
            return $this->response->errorForbidden('设置性别失败');
        }
        return response()->json(['message'=>"设置成功"]);
    }

    /**
     * 设置资料（初次登录）
     */
    public function setinfo(Request $request){
        $user = auth('api')->user();

        $validator = Validator::make($request->all(), [
            'nickname' => 'required|between:2,8',
            'birthday' => 'required',
            'avatar' => 'required',
        ], [
            'nickname.required'=>"昵称不能为空",
            'nickname.between'=>"昵称长度必须在2~8之间",
            'birthday.required'=>"生日不能为空",
            'avatar.required'=>"头像不能为空",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }

        if(UserInfoModel::where(['nickname'=>$request->nickname])->where('user_id', '!=' , $user->id)->first()){
            return $this->response->errorForbidden('昵称已被使用');
        }
        //邀请码设置
        $pid = 0;
        if(isset($request->ycode) && $request->ycode!=""){
            if(!$puser = User::where(['ycode'=>$request->ycode])->first()){
                return $this->response->errorForbidden("邀请码不存在");
            }
            $pid = $puser->id;
        }

        DB::beginTransaction();
        try {
            UserInfoModel::firstOrCreate([
                'user_id' => $user->id,
                'avatar' =>$request->avatar,
                'nickname' =>$request->nickname,
                'birthday' =>$request->birthday,
            ]);
            if($pid!=0){
               $user->pid = $pid;
               $user->save();
            }
            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            return $this->response->errorForbidden($e->getMessage());
        }
        return response()->json(['message'=>"设置成功"]);
    }

    /**
     * 获取个人资料
     */
    public function getinfo(){
        $user = auth('api')->user();
        $userinfo = UserInfoModel::where('user_id', $user->id)->first();

        $userinfo['hobby'] = explode(',',$userinfo['hobby']);
        unset($userinfo['photo']);
        unset($userinfo['video']);
        return response()->json($userinfo);
    }


    /**
     * 修改个人资料
     */
    public function updateinfo(Request $request){
        $user = auth('api')->user();
        $validator = Validator::make($request->all(), [
            'nickname' => 'required',
            'height' => 'integer',
            'weight' => 'integer',
        ], [
            'nickname.required'=>"昵称必须",
            'height.integer'=>"身高为整数",
            'weight.integer'=>"体重为整数",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        $userinfo = UserInfoModel::where('user_id', $user->id)->first();
        if($request->nickname!=$userinfo->nickname){
            if(UserInfoModel::where(['nickname'=>$request->nickname])->first()){
                return $this->response->errorForbidden('昵称已被使用');
            }
        }
        if(UserInfoModel::where('user_id', $user->id)->update($request->input())){
            return response()->json(['message'=>"修改成功"]);
        }else{
            return $this->response->errorForbidden("修改失败");
        }
    }

    /**
     * 修改个人更多介绍
     */
    public function updateext(Request $request){
        $user = auth('api')->user();
        if(UserInfoModel::where('user_id', $user->id)->update($request->input())){
            return response()->json(['message'=>"修改成功"]);
        }else{
            return $this->response->errorForbidden("修改失败");
        }
    }

    /**
     * 获取照片和视频
     */
    public function get_photo(){
        try {
            $user = auth('api')->user();
            $userinfo = DB::table('users_info')->where(['user_id'=>$user->id])->select('photo','video')->first();
            $userinfo->photo = json_decode($userinfo->photo,true);
            $userinfo->video = json_decode($userinfo->video,true);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($userinfo);
    }

    /**
     * 上传照片或者视频
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
        public function upload_file(Request $request){
        try {
            if($request->post('url')==''){
                throw new Exception("请选择上传内容");
            }
            $user = auth('api')->user();
            $userinfo = UserInfoModel::query()->where('user_id',$user->id)->first();
            if($request->type==1){
                //图片
                $user_photo = json_decode($userinfo->photo,true);
                $user_photo []= $request->post('url');
                $userinfo->photo = json_encode($user_photo);
            }else{
                //视频
                $user_video = json_decode($userinfo->video,true);
                $user_video []= $request->post('url');
                $userinfo->video = json_encode($user_video);
            }
            $userinfo->save();
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json(['message'=>'上传成功']);
    }



    /**
     * 获取VIP
     */
    public function get_vip(){
        try {
            $res = VipModel::query()->orderBy('id','asc')->get();
            foreach ($res as $k=>$v){
                $res[$k]['rights'] = json_decode($v['rights'],true);
            }
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }

    /**
     * 获取当前vip信息
     */
    public function get_vip_info(){
        try {
            $user = auth('api')->user();
            $user_info = UserInfoModel::query()->where('user_id',$user->id)->first();
            $res['avatar'] = $user_info->avatar;
            $res['nickname'] = $user_info->nickname;
            $res['is_vip'] = $user->is_vip;
            if($user->is_vip>0){
                $info = UserVipLogModel::query()->where(['user_id'=>$user->id])->first();
                $res['end_day'] = date("Y-m-d",$info->end_day);
            }else{
                $res['end_day'] = "";
            }
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }

    /**
     * 购买/续费vip
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function buy_vip(Request $request){
        try {
            $user = auth('api')->user();
            $param['id'] = $request->id;  //vip id
            $param['user_id'] = $user->id;
            $param['payment'] = $request->payment; //支付方式 1微信  2支付宝
            $res = $this->userService->buy_vip($param);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }


    /**
     * 问题反馈
     * @param Request $request
     * @return \Dingo\Api\Http\Response|void
     */
    public function problem(Request $request){
        try {
            $user = auth('api')->user();
            $param = new ProblemParam();
            $param->user_id = $user->id;
            $param->content = $request->post('content');
            $param->img_url = $request->post('img_url');
            $param->status = 0;
            $this->userService->problem($param);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json(['message'=>"提交成功"]);
    }

    /**
     * 看过我
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function looked_me(Request $request){
        try {
            $user = auth('api')->user();
            $param['user_id'] = $user->id;
            $res =$this->userService->looked_me($param);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }

    /**
     * 人脸对比
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function check_auth(Request $request){
        $apiFace = new \AipFace(env('BAI_DU_YUN_APP_ID'),env('BAI_DU_YUN_API_KEY'),env('BAI_DU_YUN_SECRET_KEY'));
        try {
           $images = array(
                array(
                    'image' => base64_encode(file_get_contents('https://cdn.learnku.com/uploads/images/202008/13/38389/9wQkrPvdVv.jpg!large')),
                    'image_type' => 'BASE64',
                ),
                array(
                    'image' => base64_encode(file_get_contents('https://cdn.learnku.com/uploads/images/202008/13/38389/9wQkrPvdVv.jpg!large')),
                    'image_type' => 'BASE64',
                ),
            );
            $res = $apiFace->match($images);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }

    /**
     * 黑名单
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function black_list(Request $request){
        try {
            $res = $this->userService->black_list();
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }

    /**
     * 移除黑名单
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function del_black(Request $request){
        try {
            $this->userService->del_black($request->id);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json(['message'=>'操作成功']);
    }

    /**
     * 设置在线状态和通知开关
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function online_status(Request $request){
        try {
            $res=$this->userService->online_status($request);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json(['message'=>'操作成功','data'=>$res]);
    }


}
